==> 0.0.4.tar.gz: lib/ccavenue_payment_gateway.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class CcavenuePaymentGateway {
  static const MethodChannel _channel = MethodChannel('ccavenue_payment_gateway');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
  //[cCAvenueInit] Initialized the field requried for Payment GateWay
  // [transUrl] Transaction Url
  // [rsakeyUrl] RSA Key Url merchant Server getRSA API/
  // [accessCode] Access Code given by CCAvenue
  // [merchantId] merchantId Code given by CCAvenue
  // [orderId] orderId you generate it or get this from merchant
  // [currencyType] currencyType Specify the currency type Like "INR","EU"...etc Please follow the documentation by CCAvenue
  // [amount] Transaction Amount
  // [cancelUrl] when the user cancel the request
  // [redirectUrl] After the Transaction it will redirect and shows the status either Success or Failed
  static Future<void> cCAvenueInit({
    required String transUrl,
    required String rsaKeyUrl,
    required String accessCode,
    required String merchantId,
    required String orderId,
    required String currencyType,
    required String amount,
    required String cancelUrl,
    required String redirectUrl,
  }) async {
    await _channel.invokeMethod('CcavenuePaymentGatewayInit', {
      'transUrl': transUrl ,
      'rsaKeyUrl': rsaKeyUrl ,
      'accessCode': accessCode,
      'merchantId': merchantId,
      'orderId': orderId ,
      'currencyType': currencyType ,
      'amount': amount ,
      'cancelUrl': cancelUrl ,
      'redirectUrl': redirectUrl
    });
  }
}

==> 0.0.5.tar.gz: lib/ccavenue_payment_gateway.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class CcavenuePaymentGateway {
  static const MethodChannel _channel = MethodChannel('ccavenue_payment_gateway');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
  //[cCAvenueInit] Initialized the field requried for Payment GateWay
  // [transUrl] Transaction Url
  // [rsakeyUrl] RSA Key Url merchant Server getRSA API/
  // [accessCode] Access Code given by CCAvenue
  // [merchantId] merchantId Code given by CCAvenue
  // [orderId] orderId you generate it or get this from merchant
  // [currencyType] currencyType Specify the currency type Like "INR","EU"...etc Please follow the documentation by CCAvenue
  // [amount] Transaction Amount
  // [cancelUrl] when the user cancel the request
  // [redirectUrl] After the Transaction it will redirect and shows the status either Success or Failed
  static Future<void> cCavenuePaymentGatewayInit({
    required String transUrl,
    required String rsaKeyUrl,
    required String accessCode,
    required String merchantId,
    required String orderId,
    required String currencyType,
    required String amount,
    required String cancelUrl,
    required String redirectUrl,
  }) async {
    await _channel.invokeMethod('ccAvenue_gateway_init', {
      'transUrl': transUrl ,
      'rsaKeyUrl': rsaKeyUrl ,
      'accessCode': accessCode,
      'merchantId': merchantId,
      'orderId': orderId ,
      'currencyType': currencyType ,
      'amount': amount ,
      'cancelUrl': cancelUrl ,
      'redirectUrl': redirectUrl
    });
  }
}
